<?php

/*
mailchimp api version3 wrapper by Drew McLellan
https://github.com/drewm/mailchimp-api
*/

/**
 * Super-simple, minimum abstraction MailChimp API v3 wrapper
 * MailChimp API v3: http://developer.mailchimp.com
 * This wrapper: https://github.com/drewm/mailchimp-api
 *
 * @author Drew McLellan <drew.mclellan@gmail.com>
 * @version 2.2
 */
class MailChimpRSVP
{
    private $api_key;
    private $api_endpoint = 'https://<dc>.api.mailchimp.com/3.0';
    /*  SSL Verification
        Read before disabling:
        http://snippets.webaware.com.au/howto/stop-turning-off-curlopt_ssl_verifypeer-and-fix-your-php-config/
    */
    public $verify_ssl = true;
    private $request_successful = false;
    private $last_error         = '';
    private $last_response      = array();
    private $last_request       = array();
    /**
     * Create a new instance
     * @param string $api_key Your MailChimp API key
     * @throws \Exception
     */
    public function __construct($api_key)
    {
        $this->api_key = $api_key;
        if (strpos($this->api_key, '-') === false) {
            throw new \Exception('Invalid MailChimp API key supplied.');
        }
        list(, $data_center) = explode('-', $this->api_key);
        $this->api_endpoint  = str_replace('<dc>', $data_center, $this->api_endpoint);
        $this->last_response = array('headers' => null, 'body' => null);
    }
    /**
     * Create a new instance of a Batch request. Optionally with the ID of an existing batch.
     * @param string $batch_id Optional ID of an existing batch, if you need to check its status for example.
     * @return Batch            New Batch object.
     */
    public function new_batch($batch_id = null)
    {
        return new Batch($this, $batch_id);
    }
    /**
     * Convert an email address into a 'subscriber hash' for identifying the subscriber in a method URL
     * @param   string $email The subscriber's email address
     * @return  string          Hashed version of the input
     */
    public function subscriberHash($email)
    {
        return md5(strtolower($email));
    }
    /**
     * Was the last request successful?
     * @return bool  True for success, false for failure
     */
    public function success()
    {
        return $this->request_successful;
    }
    /**
     * Get the last error returned by either the network transport, or by the API.
     * If something didn't work, this should contain the string describing the problem.
     * @return  array|false  describing the error
     */
    public function getLastError()
    {
        return $this->last_error;
    }
    /**
     * Get an array containing the HTTP headers and the body of the API response.
     * @return array  Assoc array with keys 'headers' and 'body'
     */
    public function getLastResponse()
    {
        return $this->last_response;
    }
    /**
     * Get an array containing the HTTP headers and the body of the API request.
     * @return array  Assoc array
     */
    public function getLastRequest()
    {
        return $this->last_request;
    }
    /**
     * Make an HTTP DELETE request - for deleting data
     * @param   string $method URL of the API request method
     * @param   array $args Assoc array of arguments (if any)
     * @param   int $timeout Timeout limit for request in seconds
     * @return  array|false   Assoc array of API response, decoded from JSON
     */
    public function delete($method, $args = array(), $timeout = 10)
    {
        return $this->makeRequest('delete', $method, $args, $timeout);
    }
    /**
     * Make an HTTP GET request - for retrieving data
     * @param   string $method URL of the API request method
     * @param   array $args Assoc array of arguments (usually your data)
     * @param   int $timeout Timeout limit for request in seconds
     * @return  array|false   Assoc array of API response, decoded from JSON
     */
    public function get($method, $args = array(), $timeout = 10)
    {
        return $this->makeRequest('get', $method, $args, $timeout);
    }
    /**
     * Make an HTTP PATCH request - for performing partial updates
     * @param   string $method URL of the API request method
     * @param   array $args Assoc array of arguments (usually your data)
     * @param   int $timeout Timeout limit for request in seconds
     * @return  array|false   Assoc array of API response, decoded from JSON
     */
    public function patch($method, $args = array(), $timeout = 10)
    {
        return $this->makeRequest('patch', $method, $args, $timeout);
    }
    /**
     * Make an HTTP POST request - for creating and updating items
     * @param   string $method URL of the API request method
     * @param   array $args Assoc array of arguments (usually your data)
     * @param   int $timeout Timeout limit for request in seconds
     * @return  array|false   Assoc array of API response, decoded from JSON
     */
    public function post($method, $args = array(), $timeout = 10)
    {
        return $this->makeRequest('post', $method, $args, $timeout);
    }
    /**
     * Make an HTTP PUT request - for creating new items
     * @param   string $method URL of the API request method
     * @param   array $args Assoc array of arguments (usually your data)
     * @param   int $timeout Timeout limit for request in seconds
     * @return  array|false   Assoc array of API response, decoded from JSON
     */
    public function put($method, $args = array(), $timeout = 10)
    {
        return $this->makeRequest('put', $method, $args, $timeout);
    }
    /**
     * Performs the underlying HTTP request. Not very exciting.
     * @param  string $http_verb The HTTP verb to use: get, post, put, patch, delete
     * @param  string $method The API method to be called
     * @param  array $args Assoc array of parameters to be passed
     * @param int $timeout
     * @return array|false Assoc array of decoded result
     * @throws \Exception
     */
    private function makeRequest($http_verb, $method, $args = array(), $timeout = 10)
    {
        if (!function_exists('curl_init') || !function_exists('curl_setopt')) {
            throw new \Exception("cURL support is required, but can't be found.");
        }
        $url = $this->api_endpoint . '/' . $method;
        $this->last_error         = '';
        $this->request_successful = false;
        $response                 = array('headers' => null, 'body' => null);
        $this->last_response      = $response;
        $this->last_request = array(
            'method'  => $http_verb,
            'path'    => $method,
            'url'     => $url,
            'body'    => '',
            'timeout' => $timeout,
        );
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array(
            'Accept: application/vnd.api+json',
            'Content-Type: application/vnd.api+json',
            'Authorization: apikey ' . $this->api_key
        ));
        curl_setopt($ch, CURLOPT_USERAGENT, 'DrewM/MailChimp-API/3.0 (github.com/drewm/mailchimp-api)');
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_TIMEOUT, $timeout);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, $this->verify_ssl);
        curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_0);
        curl_setopt($ch, CURLOPT_ENCODING, '');
        curl_setopt($ch, CURLINFO_HEADER_OUT, true);
        switch ($http_verb) {
            case 'post':
                curl_setopt($ch, CURLOPT_POST, true);
                $this->attachRequestPayload($ch, $args);
                break;
            case 'get':
                $query = http_build_query($args);
                curl_setopt($ch, CURLOPT_URL, $url . '?' . $query);
                break;
            case 'delete':
                curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'DELETE');
                break;
            case 'patch':
                curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'PATCH');
                $this->attachRequestPayload($ch, $args);
                break;
            case 'put':
                curl_setopt($ch, CURLOPT_CUSTOMREQUEST, 'PUT');
                $this->attachRequestPayload($ch, $args);
                break;
        }
        $response['body']    = curl_exec($ch);
        $response['headers'] = curl_getinfo($ch);
        if (isset($response['headers']['request_header'])) {
            $this->last_request['headers'] = $response['headers']['request_header'];
        }
        if ($response['body'] === false) {
            $this->last_error = curl_error($ch);
        }
        curl_close($ch);
        $formattedResponse = $this->formatResponse($response);
        $this->determineSuccess($response, $formattedResponse);
        return $formattedResponse;
    }
    /**
     * Encode the data and attach it to the request
     * @param   resource $ch cURL session handle, used by reference
     * @param   array $data Assoc array of data to attach
     */
    private function attachRequestPayload(&$ch, $data)
    {
        $encoded = json_encode($data);
        $this->last_request['body'] = $encoded;
        curl_setopt($ch, CURLOPT_POSTFIELDS, $encoded);
    }
    /**
     * Decode the response and format any error messages for debugging
     * @param array $response The response from the curl request
     * @return array|false    The JSON decoded into an array
     */
    private function formatResponse($response)
    {
        $this->last_response = $response;
        if (!empty($response['body'])) {
            return json_decode($response['body'], true);
        }
        return false;
    }
    /**
     * Check if the response was successful or a failure. If it failed, store the error.
     * @param array $response The response from the curl request
     * @param array|false $formattedResponse The response body payload from the curl request
     * @return bool     If the request was successful
     */
    private function determineSuccess($response, $formattedResponse)
    {
        $status = $this->findHTTPStatus($response, $formattedResponse);
        if ($status >= 200 && $status <= 299) {
            $this->request_successful = true;
            return true;
        }
        if (isset($formattedResponse['detail'])) {
            $this->last_error = sprintf('%d: %s', $formattedResponse['status'], $formattedResponse['detail']);
            return false;
        }
        $this->last_error = 'Unknown error, call getLastResponse() to find out what happened.';
        return false;
    }
    /**
     * Find the HTTP status code from the headers or API response body
     * @param array $response The response from the curl request
     * @param array|false $formattedResponse The response body payload from the curl request
     * @return int  HTTP status code
     */
    private function findHTTPStatus($response, $formattedResponse)
    {
        if (!empty($response['headers']) && isset($response['headers']['http_code'])) {
            return (int) $response['headers']['http_code'];
        }
        if (!empty($response['body']) && isset($formattedResponse['status'])) {
            return (int) $formattedResponse['status'];
        }
        return 418;
    }
}

  // Avoid name collisions.
  if (!class_exists('RSVPMaker_Email_Options'))
      : class RSVPMaker_Email_Options
      {
          // this variable will hold url to the plugin  
          var $plugin_url;
          
          // name for our options in the DB
          var $db_option = 'chimp';
          
          // Initialize the plugin
          function RSVPMaker_Email_Options()
          {
              $this->plugin_url = trailingslashit( WP_PLUGIN_URL.'/'. dirname( plugin_basename(__FILE__) ) );

              // add options Page
              add_action('admin_menu', array(&$this, 'admin_menu'));
              
          }
          
          // hook the options page
          function admin_menu()
          {
              add_options_page('RSVP Mailer', 'RSVP Mailer', 4, basename(__FILE__), array(&$this, 'handle_options'));
          }
          
          // handle plugin options
          function get_options()
          {
              $email = get_option('admin_email');
			  // default values
              $options = array(
			  'email-from' => $email
			  ,'email-name' => get_bloginfo('name')
			  ,'reply-to' => $email
			  ,'chimp-key' => ''
			  ,'chimp-list' => ''
			  ,'mailing_address' => ''
			  ,'chimp_add_new_users' => ''
			  ,'company' => ''
			  ,"add_notify" => $email
			  );
              
              // get saved options
              $saved = get_option($this->db_option);
              
              // assign them
              if (!empty($saved)) {
                  foreach ($saved as $key => $option)
                      $options[$key] = $option;
              }
              
              // update the options if necessary
              if ($saved != $options)
                  update_option($this->db_option, $options);
              
              //return the options  
              return $options;
          }
          
          // Set up everything
          function install()
          {
              // set default options
              $this->get_options();
          }
          
          // handle the options page
          function handle_options()
          {
              $options = $this->get_options();
              
              if ($_POST) {
              		
              		//check security
              		check_admin_referer('email-nonce');
              		
                  //$options = array();
                  foreach ($options as $name => $value)
				  	{
					$options[$name] = $_POST[$name];
				  	}
                  update_option($this->db_option, $options);

				if($_POST["add_cap"])
					{
						foreach($_POST["add_cap"] as $role => $type)
							{
								if($type == 'publish')
									add_rsvpemail_caps_role($role, true);
								else
									add_rsvpemail_caps_role($role);								
							}
					}

				if($_POST["remove_cap"])
					{
						foreach($_POST["remove_cap"] as $role => $type)
							{
								remove_rsvpemail_caps_role($role);								
							}
					}
                  
                  echo '<div class="updated fade"><p>Plugin settings saved.</p></div>';
              }
              
              // URL for form submit, equals our current page
              $action_url = $_SERVER['REQUEST_URI'];
; ?>
<div class="wrap" style="max-width:950px !important;">
	<h2>RSVPMaker Email Options</h2>
				
	<div id="poststuff" style="margin-top:10px;">

	 <div id="mainblock" style="width:710px">
	 
		<div class="dbx-content">

		 	<form name="Email Options" action="<?php echo $action_url ; ?>" method="post">
					<input type="hidden" name="submitted" value="1" /> 
					
					<?php wp_nonce_field('email-nonce'); ?>
					
                    <p>Email From: 
                      <input type="text" name="email-from" id="email-from" value="<?php echo $options["email-from"]; ?>" />
                    </p>
                    <p>Email Name: 
                      <input type="text" name="email-name" id="email-name" value="<?php echo $options["email-name"]; ?>" />
                    </p>
                    <p>MailChimp API-Key: 
                      <input type="text" name="chimp-key" id="chimp-key" value="<?php echo $options["chimp-key"]; ?>" />
                    <br /><a href="http://kb.mailchimp.com/integrations/api-integrations/about-api-keys">Get an API key for MailChimp</a>
                    </p>
                    <p>Default List: 
                      <select name="chimp-list" id="chimp-list" ><?php echo mailchimp_list_dropdown($options["chimp-key"], $options["chimp-list"]); ?></select>
                    </p>
                    <p>Attempt to Subscribe New WordPress user emails: 
                      <input type="checkbox" name="chimp_add_new_users" id="chimp_add_new_users" value="1" <?php echo ($options["chimp_add_new_users"]) ? ' checked="checked" ' : ''; ?> />
                    </p>
                    <p>Email to notify on API listSubscribe success/failure (optional): 
                      <input type="text" name="add_notify" id="add_notify" value="<?php echo $options["add_notify"]; ?>" />
                    </p>

                    <p>Mailing Address: 
                      <input type="text" name="mailing_address" id="mailing_address" value="<?php echo $options["mailing_address"]; ?>" />
                    </p>
                    <p>Company: 
                      <input type="text" name="company" id="company" value="<?php echo $options["company"]; ?>" />
                    </p>
<h3>Who Can Publish and Send Email?</h3>
<p>By default, only the administrator has this right, but you can add it to other roles.</p>
<?php $allroles = get_editable_roles(  ); 
foreach($allroles as $slug => $properties)
{
if($slug == 'administrator')
	continue;
	echo $properties["name"];
	if($properties["capabilities"]['publish_rsvpemails'])
		printf(' %s <input type="checkbox" name="remove_cap[%s]" value="1" /> %s <br />',__('can publish and send broadcasts','rsvpmaker'),$slug,__('Remove','rsvpmaker'));
	elseif($properties["capabilities"]['edit_rsvpemails'])
		printf(' %s <input type="checkbox" name="remove_cap[%s]" value="1" /> %s <br />',__('can edit draft emails','rsvpmaker'),$slug,__('Remove','rsvpmaker'));
	else
		printf(' %s <input type="radio" name="add_cap[%s]" value="edit" /> %s <input type="radio" name="add_cap[%s]" value="publish" /> %s <br />',__('grant right to','rsvpmaker'),$slug,__('Edit','rsvpmaker'),$slug,__('Publish and Send','rsvpmaker'));
}
?>

              <div class="submit"><input type="submit" name="Submit" value="Update" /></div>
			</form>

<?php
;
?>

		</div>
				
	 </div>

	</div>

</p>
</div>
<?php              
          }
      }
  
  else
      : exit("Class already declared!");
  endif;
  
  // create new instance of the class
  $RSVPMaker_Email_Options = new RSVPMaker_Email_Options();
  //// print_r($RSVPMaker_Email_Options);
  if (isset($RSVPMaker_Email_Options)) {
      // register the activation function by passing the reference to our instance
      register_activation_hook(__FILE__, array(&$RSVPMaker_Email_Options, 'install'));
  }

function RSVPMaker_Chimp_Add($email, $merge_vars) {
$chimp_options = get_option('chimp');

$apikey = $chimp_options["chimp-key"];
$listId = $chimp_options["chimp-list"]; 

try {
    $MailChimp = new MailChimpRSVP($apikey);
} catch (Exception $e) {
		mail($chimp_options["add_notify"],"RSVPMaker_Chimp_Add error for $email ",$e->getMessage() .' email'.$email.' '.var_export($merge_vars,true));
    return;
}

$MailChimp = new MailChimpRSVP($apikey);

$result = $MailChimp->post("lists/$listId/members", array(
                'email_address' => $email,
                'merge_fields'        => $merge_vars,
				'status' => 'subscribed'));

	if($chimp_options["add_notify"])
	{
		 if($MailChimp->success() ) {
			mail($chimp_options["add_notify"],"RSVPMaker_Chimp_Add invite sent to $email ",var_export($merge_vars, true));
		}
		else  {
			// factor out already on list?
			mail($chimp_options["add_notify"],"RSVPMaker_Chimp_Add error for $email ",$MailChimp->getLastError());
		}
	}
}

//attempt to add people who register with website, if specified on user form
if($chimp_options["chimp_add_new_users"])
	add_action('user_register','RSVPMaker_register_chimpmail');

function RSVPMaker_register_chimpmail($user_id) {
$new_user = get_userdata($user_id);
$email = $new_user->user_email;
$merge_vars["FNAME"] = $new_user->first_name;
$merge_vars["LNAME"] = $new_user->last_name;
RSVPMaker_Chimp_Add($email, $merge_vars);
}

add_filter( 'cron_schedules', 'rsvpmaker_add_weekly_schedule' ); 
function rsvpmaker_add_weekly_schedule( $schedules ) {
  $schedules['weekly'] = array(
    'interval' => 7 * 24 * 60 * 60, //7 days * 24 hours * 60 minutes * 60 seconds
    'display' => __( 'Once Weekly', 'rsvpmaker' )
  );
  return $schedules;
}

function cron_schedule_options () {
global $post;
$args = array('post_id' => $post->ID);
$cron = get_post_meta($post->ID,'rsvpmaker_cron_email',true);
$chimp_options = get_option('chimp');
?>
<h3>Scheduled Email</h3>
<p><input type="checkbox" name="cron_active" value="1" <?php if(!empty($cron["cron_active"])) echo 'checked="checked"' ?> > <?php echo __('Create Schedule','rsvpmaker');?> <?php if($chimp_options["chimp-key"]) { ?> <input type="checkbox" name="cron_mailchimp" value="1"  <?php if(!empty($cron["cron_mailchimp"])) echo 'checked="checked"' ?> > <?php echo __('Send to MailChimp List','rsvpmaker'); } ?> <input type="checkbox" name="cron_members" value="1"  <?php if(!empty($cron["cron_members"])) echo 'checked="checked"' ?> > <?php echo __('Send to Website Members','rsvpmaker');?> <input type="checkbox" name="cron_preview" value="1"  <?php if(!empty($cron["cron_preview"])) echo 'checked="checked"' ?> > <?php echo __('Send preview (preveiw email set above)','rsvpmaker');?></p>
<p><?php echo __('Day:','rsvpmaker');?>: <select name="cronday">
<?php
fix_timezone();
$timestamp = strtotime('+1 hour');
$day = (empty($cron["cron_active"])) ? (int) date('w',$timestamp) : $cron["cronday"];
$hour = (empty($cron["cron_active"])) ? (int) date('G',$timestamp)  : $cron["cronhour"];

$days = array(__('Sunday','rsvpmaker'),__('Monday','rsvpmaker'),__('Tuesday','rsvpmaker'),__('Wednesday','rsvpmaker'),__('Thursday','rsvpmaker'),__('Friday','rsvpmaker'),__('Saturday','rsvpmaker'));
foreach($days as $index => $daytext)
	{
	$selected = ($index == $day) ? ' selected="selected" ' : '';
	printf('<option  value="%s" %s>%s</option>',$index,$selected,$daytext);
	}
?>
</select>
<?php echo __('Hour:','rsvpmaker');?> <select name="cronhour"> 
<?php
for($i=0; $i < 24; $i++)
	{
	$selected = ($i == $hour) ? ' selected="selected" ' : '';
	$padded = ($i < 10) ? '0'.$i : $i;
	if($i == 0)
		$twelvehour = "12 a.m.";
	elseif($i == 12)
		$twelvehour = "12 p.m.";
	elseif($i > 12)
		$twelvehour = ($i - 12) ." p.m.";
	else		
		$twelvehour = $i." a.m.";

	printf('<option  value="%s" %s>%s / %s</option>',$padded,$selected,$twelvehour,$padded);
	}
?>
</select>
Recurrence <select name="cronrecur"><option value=""><?php echo __('None','rsvpmaker');?></option>
<?php
$sked_meta = (empty($cron["cronrecur"])) ? ''  : $cron["cronrecur"];
$schedules = array('weekly','daily');
foreach ($schedules as $sked)
	{
	$selected = ($sked == $sked_meta) ? ' selected="selected" ' : '';
	printf('<option  value="%s" %s>%s</option>',$sked,$selected,$sked);
	}
?>
</select>
</p>
<?php
if(!empty($cron["cron_active"]))
{
	$t = strtotime($days[$cron["cronday"]]);
	$stamp = date('Y-m-d',$t);
$editorsnote = get_post_meta($post->ID,'editorsnote',true);
if(!isset($editorsnote["stamp"]) || ($editorsnote["stamp"] != $stamp))
	$editorsnote["add_to_head"] = $editorsnote["note"] = '';
?>
<h3>Add Editor's Note for <?php echo $stamp;?></h3>
<input type="hidden" name="editorsnote[stamp]" value="<?php echo $stamp; ?>">
<p>Subject: <input type="text" name="editorsnote[add_to_head]" value="<?php echo $editorsnote["add_to_head"]; ?>" /></p>
<p><textarea rows="5" cols="80" name="editorsnote[note]"><?php echo $editorsnote["note"]; ?></textarea></p>
<?php
}

}

function RSVPMaker_draw_blastoptions() {

global $post;
$chimp_options = get_option('chimp');
if(empty($chimp_options["email-from"]))
	{
	printf('<p>%s: <a href="%s">%s</a></p>',__('You must fill in the RSVP Mailer settings before first use','rsvpmaker'),admin_url('options-general.php?page=rsvpmaker-email.php'),__('Settings','rsvpmaker'));
	return;
	}
if($_GET["post"])
{
$custom_fields = get_post_custom($post->ID);
$permalink = get_permalink($post->ID);
; ?>
<p><strong>To Send Your Message</strong></p>
<p>If you are ready to send your message, click <a href="<?php echo $permalink; ?>">View Post</a> now to view the message in the email template. You will also be sent a test or preview email that you can review before approving the email broadcast.</p>
<p>If you make more changes here, be sure you save them by clicking Update first before sending your message.</p>
<?php
}
elseif($_GET["page"] == 'email_get_content')
	;
else
{
; ?>
<p><strong>To Send Your Message</strong></p>
<p>If you are ready to send your message, click Publish, then follow the link to View Post to view the message in the email template. You will also be sent a test or preview email that you can review before approving the email broadcast.</p>
<?php
}

$template = get_rsvpmaker_email_template();
?>
<table>
<tr><td>From Name:</td><td><input type="text"  size="80" name="email[from_name]" value="<?php echo ($custom_fields["_email_from_name"][0]) ? $custom_fields["_email_from_name"][0] : $chimp_options["email-name"]; ?>" /></td></tr>
<tr><td>From Email:</td><td><input type="text" size="80"  name="email[from_email]" value="<?php echo ($custom_fields["_email_from_email"][0]) ? $custom_fields["_email_from_email"][0] : $chimp_options["email-from"]; ?>" /></td></tr>
<tr><td>Preview To:</td><td><input type="text" size="80" name="email[preview_to]" value="<?php echo ($custom_fields["_email_preview_to"][0]) ? $custom_fields["_email_preview_to"][0] : $chimp_options["email-from"]; ?>" /></td></tr>
</table>
<p><input type="checkbox" name="email[headline]" id="email[headline]" value="1" <?php echo ($custom_fields["_email_headline"][0]) ? ' checked="checked" ' : ''; ?> /> Show post title as headline in email (in addition to subject line)</p>
<p>Template <select name="email[template]">
<?php
foreach($template as $index => $value)
	{
	$c = ( $index == $custom_fields["_email_template"][0]) ? ' selected="selected" ' : '';
	echo sprintf('<option value="%d" %s>%s</option>',$index,$c,$value["slug"]);
	}
; ?>
</select></p>

<p>List <select name="email[list]">
<?php
$chosen = (isset($custom_fields["_email_list"][0])) ? $custom_fields["_email_list"][0] : $chimp_options["chimp-list"];
echo mailchimp_list_dropdown($chimp_options["chimp-key"], $chosen);
?>
</select></p>

<p>You can import the content of posts and RSVPMaker events on the <a href="<?php echo admin_url('edit.php?post_type=rsvpemail&page=email_get_content') ?>">Content for Email</a> screen.</p>

<?php
if(current_user_can('publish_rsvpemails'))
	cron_schedule_options();
}

function my_rsvpemails_menu() {

add_meta_box( 'BlastBox', 'RSVPMaker Email Options', 'RSVPMaker_draw_blastoptions', 'rsvpemail', 'normal', 'high' );

}

function save_rsvpemail_data($postID) {

if($_POST["email"]["from_name"])
	{
	global $wpdb;
	global $current_user;
	
	if($parent_id = wp_is_post_revision($postID))
		{
		$postID = $parent_id;
		}
		
		$ev = $_POST["email"];
		if(!$ev["headline"])
			$ev["headline"] = 0;
		foreach($ev as $name => $value)
			{
			$field = '_email_'.$name;
			$single = true;
			$current = get_post_meta($postID, $field, $single);
			 
			if($value && ($current == "") )
				add_post_meta($postID, $field, $value, true);
			
			elseif($value != $current)
				update_post_meta($postID, $field, $value);
			
			elseif($value == "")
				delete_post_meta($postID, $field, $current);
			}
	
	update_post_meta($postID,'editorsnote',$_POST["editorsnote"]);

	$args = array('post_id' => $postID);
	$cron_checkboxes = array("cron_active", "cron_mailchimp", "cron_members", "cron_preview");
	foreach($cron_checkboxes as $check)
		{
			$cron[$check] = (int) $_POST[$check];
		}
	if($cron["cron_active"])
		{
			//clear if previously set
			wp_clear_scheduled_hook( 'rsvpmaker_cron_email', $args );
			$cron_fields = array("cronday", "cronhour", "cronrecur");
			foreach($cron_fields as $field)
				$cron[$field] = $_POST[$field];
			update_post_meta($postID,'rsvpmaker_cron_email',$cron);
			fix_timezone();
			$days = array('Sunday','Monday','Tuesday','Wednesday','Thursday','Friday','Saturday');
			$t = strtotime($days[$cron["cronday"]] .' '.$cron["cronhour"].':00');
			if(empty($cron["cronrecur"]))
				{
					// single cron
					wp_schedule_single_event( $t, 'rsvpmaker_cron_email', $args );
				}
			else
				{
					wp_schedule_event( $t, $cron["cronrecur"], 'rsvpmaker_cron_email', $args );
				}
		}
	else
		{
		delete_post_meta($postID,'rsvpmaker_cron_email');
		wp_clear_scheduled_hook( 'rsvpmaker_cron_email', $args );
		}
	
	$message = var_export($args,true).var_export($_POST,true);
	}
}

add_action('admin_menu', 'my_rsvpemails_menu');

add_action('save_post','save_rsvpemail_data');

function default_rsvpemail_title($title) {
global $post;
if(isset($_GET["event"]) && !empty($_GET["event"]))
	{
		$id = (int) $_GET["event"];
		if($id)
		{	
		global $rsvpmaker_embed;
		if(empty($rsvpmaker_embed["subject"]))
		$rsvpmaker_embed = event_to_embed($id);
		$title .= $rsvpmaker_embed["subject"];
		$date = get_rsvp_date($id);
		fix_timezone();
		$t = strtotime($date);
		global $rsvp_options;
		$title .= ' - '.date($rsvp_options["short_date"],$t);
		}
	}
if(isset($_GET["get_post"]))
	{
		$id = (int) $_GET["get_post"];
		if($id)
		{
		global $embed_post;
		if(empty($embed_post->post_title))
			$embed_post = get_post($id);
		$title .= $embed_post->post_title;
		}
	}

return $title;
}

function default_rsvpemail_content($content) {
global $post;

if(isset($_GET["get_post"]) && !empty($_GET["get_post"]))
	{
		$content .= "INTRO\n\n";
		$parts = explode(':',$_GET["get_post"]);
		if($parts[1])
			$cq = new WP_Query('posts_per_page='.$parts[1]);
		else
			$cq = new WP_Query('posts_per_page=1&post_id='. (int) $_GET["get_post"]);
ob_start();
//// print_r($cq);
while ( $cq->have_posts() ) : $cq->the_post();
global $post;
if(!$subject)
	$subject = get_the_title();
; ?>
<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
<h1 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h1>
<div class="entry-content">

<?php 
if($_GET["get_format"] == 'content')
	the_content('Continue reading ' . get_the_title());
else
	the_excerpt();
?>
</div><!-- .entry-content -->
</div>
<?php 
endwhile;
$content .= ob_get_clean();
	}

if(isset($_GET["event"]) && !empty($_GET["event"]))
	{
		$content .= "INTRO\n\n";
		$id = (int) $_GET["event"];
		if($id)
		{
		global $rsvpmaker_embed;
		if(empty($rsvpmaker_embed["content"]))
		$rsvpmaker_embed = event_to_embed($id);		
		$content .= $rsvpmaker_embed["content"];
		}
		elseif($_GET["event"] == 'upcoming')
			$content .= "[rsvpmaker_upcoming]\n\n";
	}
return $content;
}

add_filter('default_title','default_rsvpemail_title');
add_filter('default_content','default_rsvpemail_content');

add_action( 'init', 'create_rsvpemail_post_type' );

function create_rsvpemail_post_type() {
  register_post_type( 'rsvpemail',
    array(
      'labels' => array(
        'name' => __( 'RSVP Mailer','rsvpmaker' ),
        'add_new_item' => __( 'Add New Email','rsvpmaker' ),
        'edit_item' => __( 'Edit Email','rsvpmaker' ),
        'new_item' => __( 'Emails','rsvpmaker' ),
        'singular_name' => __( 'Email','rsvpmaker' )
      ),
	'public' => true,
	'exclude_from_search' => true,
    'publicly_queryable' => true,
    'show_ui' => true, 
    'query_var' => true,
    'rewrite' => true,
    'capabilities' => array(
        'edit_post' => 'edit_rsvpemail',
        'edit_posts' => 'edit_rsvpemails',
        'edit_others_posts' => 'edit_others_rsvpemails',
        'publish_posts' => 'publish_rsvpemails',
        'read_post' => 'read_rsvpemail',
        'read_private_posts' => 'read_private_rsvpemails',
        'delete_post' => 'delete_rsvpemail'
    ),
    'hierarchical' => false,
    'menu_position' => 20,
	'menu_icon' => WP_PLUGIN_URL.'/rsvpmaker/email.gif',
    'supports' => array('title','editor')
    )
  );
}

function add_rsvpemail_caps() {
    // gets the administrator role
    $admins = get_role( 'administrator' );
    $admins->add_cap( 'edit_rsvpemail' ); 
    $admins->add_cap( 'edit_rsvpemails' ); 
    $admins->add_cap( 'edit_others_rsvpemails' ); 
    $admins->add_cap( 'publish_rsvpemails' ); 
    $admins->add_cap( 'read_rsvpemail' ); 
    $admins->add_cap( 'read_private_rsvpemails' ); 
    $admins->add_cap( 'delete_rsvpemail' ); 
}

function add_rsvpemail_caps_role($role, $publish = false) {
    // gets the administrator role
    $emailers= get_role( $role );
    $emailers->add_cap( 'edit_rsvpemail' ); 
    $emailers->add_cap( 'edit_rsvpemails' );
    $emailers->add_cap( 'edit_others_rsvpemails' ); 
    $emailers->add_cap( 'read_rsvpemail' ); 
    $emailers->add_cap( 'read_private_rsvpemails' ); 
    $emailers->add_cap( 'delete_rsvpemail' ); 
	if($publish)
    	$emailers->add_cap( 'publish_rsvpemails' ); 
}

function remove_rsvpemail_caps_role($role) {
    // gets the administrator role
    $emailers= get_role( $role );
    $emailers->remove_cap( 'edit_rsvpemail' ); 
    $emailers->remove_cap( 'edit_rsvpemails' );
    $emailers->remove_cap( 'edit_others_rsvpemails' ); 
    $emailers->remove_cap( 'read_rsvpemail' ); 
    $emailers->remove_cap( 'read_private_rsvpemails' ); 
    $emailers->remove_cap( 'delete_rsvpemail' ); 
   	$emailers->remove_cap( 'publish_rsvpemails' ); 
}

add_action( 'admin_init', 'add_rsvpemail_caps');
add_action("template_redirect", 'rsvpemail_template_redirect');

// Template selection
function rsvpemail_template_redirect()
{

global $wp;
global $wp_query;

	if ($wp->query_vars["post_type"] == "rsvpemail")
	{
		if (have_posts())
		{
			include(WP_PLUGIN_DIR . '/rsvpmaker/rsvpmaker-email-template.php');
			die();
		}
		else
		{
			$wp_query->is_404 = true;
		}
	}
}

function rsvpmaker_text_version($content, $chimpfooter_text)
{
//match text links (not link around image, which would start with <)
$content = str_replace('*|MC:SUBJECT|*','',$content);
preg_match_all('/href="([^"]+)[^>]*>([^<]+)/',$content,$matches);
if(!empty($matches))
	{
	$content .= "\n\nLinks:\n\n";
		foreach($matches[1] as $index => $link)
			{
			$content .= $matches[2][$index] ."\n"; //anchor text	
			$content .= $link ."\n\n";
			}
	}
$text = trim(strip_tags($content));
$text = preg_replace("/[\r\n]{3,}/","\n\n",$text);

$text .= $chimpfooter_text;
return $text;
}

function rsvpmaker_personalize_email($content,$to,$description = '') {
$chimp_options = get_option('chimp');
global $post;
$content = str_replace('*|EMAIL|*',$to,$content);
$content = str_replace('*|UNSUB|*','mailto:'.$chimp_options['email-from'].'?subject=Unsubscribe',$content);
$content = str_replace('*|REWARDS|*','',$content);
$content = str_replace('*|LIST:DESCRIPTION|*',$description,$content);
$content = str_replace('*|LIST:ADDRESS|*',$chimp_options['mailing_address'],$content);
$content = str_replace('*|LIST:COMPANY|*',$chimp_options['company'],$content);
$content = str_replace('*|CURRENT_YEAR|*',date('Y'),$content);
$content = str_replace('*|ARCHIVE|*',get_permalink($post->ID),$content);

$content = str_replace(' | <a href="*|FORWARD|*">Forward to a friend</a> | <a href="*|UPDATE_PROFILE|*">Update your profile</a>','',$content);
$content = str_replace('Forward to a friend:
*|FORWARD|*','',$content);
$content = str_replace('Update your profile:
*|UPDATE_PROFILE|*','',$content);
return $content;	
}

function rsvpmaker_email_send_ui($chimp_html, $chimp_text, $rsvp_html, $rsvp_text)
{
global $post;
global $custom_fields;
global $wpdb;
$chimp_options = get_option('chimp');

ob_start();

if(!current_user_can('publish_rsvpemails') )
	return;

$chimp_options = get_option('chimp');

if($_POST["preview"])
	{
	$previewto = trim($_POST["previewto"]);
	if(is_email($previewto))
		{
		echo '<p>Sending preview to '.$previewto.'</p>';
		$mail["to"] = $previewto;
		$mail["from"] = $_POST["from_email"];
		$mail["fromname"] =  stripslashes($_POST["from_name"]);
		$mail["subject"] =  stripslashes($_POST["subject"]);
		$mail["html"] = rsvpmaker_personalize_email($rsvp_html,$mail["to"],'You were sent this message as a preview');
		$mail["text"] = rsvpmaker_personalize_email($rsvp_text,$mail["to"],'You were sent this message as a preview');
		rsvpmailer($mail);
		}
	else
		echo '<div style="color:red;">Error: '.$previewto.' not a single valid email address</div>';
		
	}

if($_POST["attendees"] && $_POST["event"])
{
$event = (int) $_POST["event"];
$event_post = get_post($event);
$sql = "SELECT * 
FROM  `wp_rsvpmaker` 
WHERE  `event` = ".$event." ORDER BY  `email` ASC";
$results = $wpdb->get_results($sql);
if(!empty($results))
{
printf('<p>Sending to %s event attendees</p>',sizeof($results));
foreach($results as $row)
	{
	$mail["to"] = $row->email;
	$mail["from"] = $_POST["from_email"];
	$mail["fromname"] =  stripslashes($_POST["from_name"]);
	$mail["subject"] =  stripslashes($_POST["subject"]);
	$mail["html"] = rsvpmaker_personalize_email($rsvp_html,$mail["to"],'This message was sent to you as an attendee at '.$event_post->post_title);
	$mail["text"] = rsvpmaker_personalize_email($rsvp_text,$mail["to"],'This message was sent to you as an attendee at '.$event_post->post_title);
	rsvpmailer($mail);		
	}
}

}

if($_POST["members"])
{
$users = get_users();
printf('<p>Sending to %s website members</p>',sizeof($users));
foreach($users as $user)
	{
	$mail["to"] = $user->user_email;
	$mail["from"] = $_POST["from_email"];
	$mail["fromname"] =  stripslashes($_POST["from_name"]);
	$mail["subject"] =  stripslashes($_POST["subject"]);
	$mail["html"] = rsvpmaker_personalize_email($rsvp_html,$mail["to"],'This message was sent to you as a member of '.$_SERVER['SERVER_NAME']);
	$mail["text"] = rsvpmaker_personalize_email($rsvp_text,$mail["to"],'This message was sent to you as a member of '.$_SERVER['SERVER_NAME']);
	$result = rsvpmailer($mail);		
	// print_r($result);
	}
}

if($_POST["mailchimp"])
{
$MailChimp = new MailChimpRSVP($chimp_options["chimp-key"]);
$listID = $_POST["mailchimp_list"];
update_post_meta($post->ID, "_email_list",$listID);
$custom_fields["_email_list"][0] = $listID;
$campaign = $MailChimp->post("campaigns", array(
                'type' => 'regular',
                'recipients'        => array('list_id' => $listID),
				'settings' => array('subject_line' => stripslashes($_POST["subject"]),'from_email' => $_POST["from_email"], 'from_name' => $_POST["from_name"], 'reply_to' => $_POST["from_email"])
));
if(!$MailChimp->success())
	{
	echo '<div>'.__('MailChimp API error','rsvpmaker').': '.$MailChimp->getLastError().'</div>';
	return;
	}

if($campaign["id"])
{
$content_result = $MailChimp->put("campaigns/".$campaign["id"].'/content', array(
'html' => $chimp_html, 'text' => $chimp_text) );
if(!$MailChimp->success())
	{
	echo '<div>'.__('MailChimp API error','rsvpmaker').': '.$MailChimp->getLastError().'</div>';
	return;
	}
//// print_r($content_result);
$send_result = $MailChimp->post("campaigns/".$campaign["id"].'/actions/send');
//// print_r($send_result);
if($MailChimp->success())
	echo '<div>'.__('Sent MailChimp campaign','rsvpmaker').': '.$campaign["id"].'</div>';
else
	echo '<div>'.__('MailChimp API error','rsvpmaker').': '.$MailChimp->getLastError().'</div>';
}

}

$permalink = get_permalink($post->ID);
$edit_link = get_edit_post_link($post->ID);

; ?>
<form method="post" action="<?php echo $permalink; ?>">

<table>
<tr><td>From Name:</td><td><input type="text"  size="50" name="from_name" value="<?php echo ($custom_fields["_email_from_name"][0]) ? $custom_fields["_email_from_name"][0] : $chimp_options["email-name"]; ?>" /></td></tr>
<tr><td>From Email:</td><td><input type="text" size="50"  name="from_email" value="<?php echo ($custom_fields["_email_from_email"][0]) ? $custom_fields["_email_from_email"][0] : $chimp_options["email-from"]; ?>" /></td></tr>
<tr><td>Subject:</td><td><input type="text"  size="50" name="subject" value="<?php echo htmlentities($post->post_title); ?>" /></td></tr>
</table>

Send<br />
<input type="checkbox" name="preview" value="1"> Preview to: <input type="text" name="previewto" value="<?php echo ($custom_fields["_email_preview_to"][0]) ? $custom_fields["_email_preview_to"][0] : $chimp_options["email-from"]; ?>" /><br />
<input type="checkbox" name="members" value="1"> Website members<br />
<?php
if(!empty($chimp_options["chimp-key"]))
{
?>
<input type="checkbox" name="mailchimp" value="1"> MailChimp list <select name="mailchimp_list">
<?php
$chosen = (isset($custom_fields["_email_list"][0])) ? $custom_fields["_email_list"][0] : $chimp_options["chimp-list"];
echo mailchimp_list_dropdown($chimp_options["chimp-key"], $chosen);
?>
</select> <br />
<?php
}
?>
<input type="checkbox" name="attendees" value="1"> Attendees <select name="event"><?php echo get_events_dropdown (); ?></select><br />
<input type="submit" name="now" value="Send Now" />
</form>
<p>Or <a href="<?php echo $edit_link; ?>">Revise</a></p>
<?php
return '<div style="background-color: #FFFFFF; color: #000000;">'.ob_get_clean().'</div>';
}

function RSVPMaker_extract_email() {

global $wpdb;

if($_POST)
	{

$chimp_options = get_option('chimp');

$apikey = $chimp_options["chimp-key"];
$listId = $chimp_options["chimp-list"];
 
	preg_match_all ("/\b[A-z0-9][\w.-]*@[A-z0-9][\w\-\.]+\.[A-z0-9]{2,6}\b/", $_POST["emails"], $emails);
	$emails = $emails[0];

	foreach($emails as $email)
		{
		$email = strtolower($email);
		$hash = md5($email);
		if($_POST["in_mailchimp"])
			{
			if(!isset($MailChimp) && !empty($apikey))
				$MailChimp = new MailChimpRSVP($apikey);
			$member = $MailChimp->get("/lists/".$listId."/members/".$hash);
			if($member["id"] )
				{
				$inchimp .= "\n<br />$email";
				continue;
				}
			}
		echo "\n<br />$email";
		}
if($inchimp)
	echo "<h3>In MailChimp</h3>$inchimp";

	}

; ?>
<div id="icon-options-general" class="icon32"><br /></div>
<h2>Extract Emails</h2>
<p>You can enter an disorganized list of emails mixed in with other text, and this utility will extract just the email addresses.</p>
<form id="form1" name="form1" method="post" action="">

  <p>
    <textarea name="emails" id="emails" cols="45" rows="5"></textarea>
  </p>
  <p>Filter out emails that:</p>
  <p>
    <input name="in_mailchimp" type="checkbox" id="in_mailchimp" checked="checked" />
  Registered in MailChimp</p>
  <p>
    <input type="submit" name="button" id="button" value="Submit" />
  </p>
</form>
<?php
}

function inline_array($text) {
$lines = explode("\n",$text);
$inline_array = array();
foreach($lines as $line)
	{
		$line = trim($line);
		if(strpos($line,'='))
			{	
			$parts = explode('=',$line);
			$inline_array[$parts[0]] = $parts[1];
			}
	}
return $inline_array;
}	
	
function rsvpemail_template () {
?>
<div id="icon-options-general" class="icon32"><br /></div>
<?php

	if(isset($_POST['rsvpmaker_email_template']))
	{
	$templates = $_POST['rsvpmaker_email_template'];
	foreach($templates as $index => $template)
		{
		$template['html'] = stripslashes($template['html']);
		$template['inline_tags'] = inline_array($template['inline_tags']);
		$template['inline_class'] = inline_array($template['inline_class']);
		$templates[$index] = $template;
		}
	update_option('rsvpmaker_email_template',$templates);
	}

?>
<h2>RSVPMaker Email Template</h2>
<form id="form1" name="form1" method="post" action="<?php echo admin_url('edit.php?post_type=rsvpemail&page=rsvpmaker_email_template'); ?>">
<?php
global $rsvp_options;

$template = get_rsvpmaker_email_template();
?>
  <p>You can create one or more templates for use with your email broadcasts.</p>
  <p>Include the [rsvpmaker_email_content] placeholder wherever your message should appear.</p>
  <p>Other placeholders like *|ARCHIVE|* are MailChimp template codes and will be replaced when your email is broadcast.</p>
  <p>Inline CSS styles work best for formatting content for distribution via email. You can specify CSS styles that should be applied to either tags or classes.</p>
<?php
foreach($template as $index => $value)
{
; ?>
<div id="temp<?php echo $index; ?>">
  <p>
    <input type="text" name="rsvpmaker_email_template[<?php echo $index; ?>][slug]" id="rsvpmaker_email_template[<?php echo $index; ?>][slug]" value="<?php echo $template[$index]["slug"]; ?>" /> <a href="#" onclick="remove_template(<?php echo $index; ?>); return false;">Remove</a>
  </p>
  <p>
    <textarea name="rsvpmaker_email_template[<?php echo $index; ?>][html]" id="rsvpmaker_email_template[<?php echo $index; ?>][html]" cols="80" rows="10"><? echo $template[$index]["html"]; ?></textarea>
  </p>
  <p>
  Tag styles<br />
    <textarea name="rsvpmaker_email_template[<?php echo $index; ?>][inline_tags]" id="rsvpmaker_email_template<?php echo $index; ?>_inline_tags" cols="80" rows="5"><? if(!empty($template[0]['inline_tags']) ) foreach($template[0]['inline_tags'] as $tag => $tagstyle) echo $tag .'='.$tagstyle."\n"; ?></textarea>
<br />Enter in the format <em>tag=color:#000000;</em>
  </p>
  <p>
  Class styles<br />
    <textarea name="rsvpmaker_email_template[<?php echo $index; ?>][inline_class]" id="rsvpmaker_email_template<?php echo $index; ?>_inline_class" cols="80" rows="5"><? if(!empty($template[0]['inline_class']) ) foreach($template[0]['inline_class'] as $class => $classstyle) echo $class .'='.$classstyle."\n"; ?></textarea>
<br />Enter in the format <em>class=color:#000000;</em>
  </p>

</div>
<?php
}
$index++;
; ?>
<div id="add_template"><button id="addtemp"> (+) Add another template</button></div>
<p>
<button>Save</button>
</p>

<script>
function remove_template(id) {
var t = document.getElementById('temp'+id);
var f = document.getElementById('form1');
f.removeChild(t);
}

jQuery(document).ready(function($){
$('#addtemp').click( function(event) {
	event.preventDefault();
	$('#add_template').html('<p><input type="text" name="rsvpmaker_email_template[<?php echo $index; ?>][slug]" id="rsvpmaker_email_template[<?php echo $index; ?>][slug]" value="<?php echo "template".($index+1); ?>" /></p><p><textarea name="rsvpmaker_email_template[<?php echo $index; ?>][html]" id="rsvpmaker_email_template[<?php echo $index; ?>][html]" cols="80" rows="10"></textarea></p><p>Tag styles<br /><textarea name="rsvpmaker_email_template[<?php echo $index; ?>][inline_tags]" id="rsvpmaker_email_template<?php echo $index; ?>_inline_tags" cols="80" rows="5"></textarea><br />Enter in the format <em>tag=color:#000000;</em></p><p>Class styles<br /><textarea name="rsvpmaker_email_template[<?php echo $index; ?>][inline_class]" id="rsvpmaker_email_template<?php echo $index; ?>_inline_class" cols="80" rows="5"></textarea><br />Enter in the format <em>class=color:#000000;</em></p>');
	} );

});

</script>

</form>

<?php

} // end rsvpemail template form

function my_rsvpemail_menu() {

$parent_slug = "edit.php?post_type=rsvpemail";
$page_title = "Email Template";
$menu_title = $page_title;
$capability = "edit_posts";
$menu_slug = "rsvpmaker_email_template";
$function = "rsvpemail_template";

add_submenu_page( $parent_slug, $page_title, $menu_title, $capability, $menu_slug, $function);

$parent_slug = "edit.php?post_type=rsvpemail";
$page_title = "Content for Email";
$menu_title = $page_title;
$capability = "edit_posts";
$menu_slug = "email_get_content";
$function = "email_get_content";

add_submenu_page( $parent_slug, $page_title, $menu_title, $capability, $menu_slug, $function);

$parent_slug = "edit.php?post_type=rsvpemail";
$page_title = "Extract Addresses";
$menu_title = $page_title;
$capability = "edit_posts";
$menu_slug = "extract";
$function = "RSVPMaker_extract_email";

add_submenu_page( $parent_slug, $page_title, $menu_title, $capability, $menu_slug, $function);

}

add_action('admin_menu', 'my_rsvpemail_menu');

function RSVPMaker_chimpshort($atts, $content = NULL ) {

$atts = shortcode_atts( array(
  'query' => 'post_type=post&posts_per_page=5',
  'format' => '',
  ), $atts );

	ob_start();
	query_posts($atts["query"]);

if ( have_posts() ) {
while ( have_posts() ) : the_post(); ?>
<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
<h3 class="entry-title"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
<?php
if($atts["format"] == 'excerpt')
	{
; ?>
<div class="excerpt-content">

<?php the_excerpt(); ?>

</div><!-- .excerpt-content -->
<?php	
	}
elseif($atts["format"] == 'full')
	{
; ?>
<div class="entry-content">

<?php the_content(); ?>

</div><!-- .entry-content -->
<?php
}
; ?>
</div>
<?php 
endwhile;
wp_reset_query();
} 
	
	$content = ob_get_clean();

	return $content;
}
add_shortcode('RSVPMaker_chimpshort', 'RSVPMaker_chimpshort');

function email_get_content () {
global $wpdb;
;?>
<div id="icon-options-general" class="icon32"><br /></div>
<h2>Content for Email</h2>

<?php

$event_options = $options = '<option value="">'.__('None selected','rsvpmaker').'</option>';
$event_options .= '<option value="upcoming">'.__('Upcoming Events','rsvpmaker').'</option>';
$future = get_future_events();
foreach($future as $event)
	{
	if(get_post_meta($event->ID,'_rsvp_on',true))
	$event_options .= sprintf('<option value="%s">%s - %s</option>'."\n",$event->ID,$event->post_title,date('F j, Y',strtotime($event->datetime)));
	}


$sql = "SELECT ID, post_title FROM $wpdb->posts WHERE post_status='publish' AND post_type='post' ORDER BY post_date DESC LIMIT 0, 50";
$wpdb->show_errors();
$results = $wpdb->get_results($sql, ARRAY_A);
if($results)
{

$posts .= "<option value=\"recent:10\">10 Most Recent Blog Posts</option>\n";
$posts .= "<option value=\"recent:5\">5 Most Recent Blog Posts</option>\n";

foreach ($results as $row)
	{
	$posts .= sprintf("<option value=\"%d\">%s</option>\n",$row["ID"],substr($row["post_title"],0,80));
	}

$posts = '<optgroup label="Recent Posts">'.$posts."</optgroup>\n";
}

?>
<form action="<?php echo admin_url('post-new.php'); ?>" method="get">
<input type="hidden" name="post_type" value="rsvpemail" />
<p>Posts: <select name="get_post"><?php echo $options.$posts; ?></select><select name="get_format">
<option value="excerpt">Excerpt</option>
<option value="content">Content -> More</option>
</select>
</p>
<p>Events: <select name="event"><?php echo $event_options; ?></select>
</select>
</p>
<button>Load Content</button>
</form>

<p><a href="#last_select" id="custom_query" name="custom_query">(+) <?php echo __('Add custom query','rsvpemail'); ?></a></p>

<p>You can add up to 5 posts, or post listings, including event listings from the RSVPMaker plugin.</p>
<p>The format parameters are:</p>
<ul>
<li><strong>Content -> More</strong> List as if on a blog page, with a link to (more...) if the &lt;!--more--&gt; tag was used in the body of the post.</li>
<li><strong>Excerpt</strong> Show only short excerpt with a link to the rest of the post.</li>
</ul>
<p>These parameters are not applied to the events.</p>
  <?php
} // end chimp get content

function rsvpmaker_email_list_okay ($rsvp) {
		$mergevars["FNAME"] = stripslashes($rsvp["first"]);
		$mergevars["LNAME"] = stripslashes($rsvp["last"]);
		RSVPMaker_Chimp_Add($rsvp["email"],$mergevars);
}

add_action('rsvpmaker_email_list_okay','rsvpmaker_email_list_okay',10,1);

function rsvpmaker_inline_styles ($content)
{
global $post;
$templates = get_rsvpmaker_email_template();
$custom_fields = get_post_custom($post->ID); 
$t_index = isset($custom_fields["_email_template"][0]) ? $custom_fields["_email_template"][0] : 0;

$content = do_shortcode($content);
preg_match_all('/(<.[^>]*>)([^<]*)/', $content, $matches);

$inline_tags = $templates[$t_index]["inline_tags"];
$inline_class = $templates[$t_index]["inline_class"];

$newcontent = '';

foreach($matches[1] as $index => $value)
	{
		$style ='';
		
		preg_match('/^<([a-z0-9]+)/',$value,$tagmatch);
		if(!empty($tagmatch))
			{
				foreach($inline_tags as $tag => $tagstyle)
				{
				if($tagmatch[1] == $tag)
					$style .= $tagstyle; 
				}

				foreach($inline_class as $class => $class_style)
				{
				//$newcontent .= $class."<br />";
				//$newcontent .= htmlentities($value)."<br />";;
				if(strpos($value, $class) )
					{
					$style .= $class_style;
					str_replace($class, '', $value);
					}
				}
				//rewind($inline_class);
			}
		if(!empty($style) && ! strpos($value,$style) )
			{ // if not already added
			if(strpos($value,'style'))
				$value = preg_replace('/style="[^"]+/',"$0;".$style,$value);
			else
				$value = str_replace('>',' style="'.$style.'" >',$value);
			}		
		$newcontent .= $value.$matches[2][$index];
	}
return $newcontent;
}

function get_rsvpmaker_email_template() {

if(!isset($_GET["reset_email_template"]))
{
$template = get_option('rsvpmaker_email_template');
if(!empty($template))
	return $template;
}

	$template[0]['slug'] = 'default';
	$template[0]['html'] = '<html>
<head>
	<title>*|MC:SUBJECT|*</title>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
</head>
<body>
<div id="background" style="width: 100%; background-color: #DDDDFF; padding: 10px; margin-top: 0;">
<div id="content" style="max-width: 600px; padding: 5px; background-color: #FFFFFF; margin-left: auto; margin-right: auto; margin-top: 10px; margin-bottom: 10px; padding-bottom: 50px;" >

<div style="font-size: small; border: thin dotted #999;">Email not displaying correctly? <a href="*|ARCHIVE|*" class="adminText">View it in your browser.</a></div>

<div class="headerBarText"><h1><a href="'.home_url().'">'.get_bloginfo('name').'</a></h1></div>

[rsvpmaker_email_content]

</div><!-- end content area -->
</div><!-- end background -->
</body>
</html>';
	$template[0]['inline_tags'] = array('h1' => 'color: #4444FF;','h2' => 'color: #4444FF;','h3' => 'color: #4444FF;');
	$template[0]['inline_class'] = array('alignright' => 'float: right; padding: 5px; background-color: #EFEFEF;','alignleft' => 'float: left; padding: 5px; background-color: #EFEFEF;','aligncenter' => 'margin-left: auto; margin-right: auto; background-color: #EFEFEF; padding: 5px;');

update_option('rsvpmaker_email_template',$template);
return $template;
}

add_shortcode('rsvpmaker_email_content', 'rsvpmaker_email_content');

function rsvpmaker_email_content ($atts, $content) {
global $wp_filter;
global $post;
$corefilters = array('convert_chars','wpautop','wptexturize');
foreach($wp_filter["the_content"] as $priority => $filters)
	foreach($filters as $name => $details)
		{
		//keep only core text processing or shortcode
		if(!in_array($name,$corefilters) && !strpos($name,'hortcode'))
			{
			$r = remove_filter( 'the_content', $name, $priority );
			}
		}
ob_start();
global $rsvp_options;
; ?>
<!-- editors note goes here -->
<div id="post-<?php the_ID(); ?>" <?php post_class(); ?>>
<?php if(get_post_meta($post->ID,"_email_headline",true)) { ; ?>
<h1 class="entry-title"><?php the_title(); ?></h1>
<?php } ; ?>
<div class="entry-content">
<?php the_content(); ?>
</div><!-- .entry-content -->
</div><!-- #post-## -->
<div class="footer"><!-- footer --></div>
<?php 
return ob_get_clean();
}

function mailchimp_list_dropdown($apikey, $chosen = '') {
if(empty($apikey))
	return '<option value="">none</option>';
try {
    $MailChimp = new MailChimpRSVP($apikey);
} catch (Exception $e) {
    return '<option value="">none '.$e->getMessage().'</option>';
}


$retval = $MailChimp->get('lists');

$options = '';
if (is_array($retval)){
	foreach ($retval["lists"] as $list){
		$s = ($chosen == $list['id']) ? ' selected="selected" ' : '';
		$options .=  '<option value= "'.$list['id'].'"'. " $s >".$list['name'].'</option>';
	}
}
return $options;
}

function event_to_embed($post_id, $embed = NULL) {
		global $email_context;
		global $rsvp_options;
		$email_context = true;
		if(empty($embed))
			$embed = get_post($post_id);
		$event_embed["subject"] = $embed->post_title;
		$event_embed["content"] = sprintf('<h1><a href="%s">',get_permalink($embed->ID));
		$event_embed["content"] .= apply_filters('the_title',$embed->post_title);
		$event_embed["content"] .= "</a></h1>\n";	
		$dateblock = rsvp_date_block($post_id);
		$event_embed["content"] .= '<div class="dateblock" style="font-weight: bold; margin-top: 5px; margin-bottom: 5px;">'.$dateblock."\n</div>\n".$rsvpconfirm.$content;
		$event_embed["content"] .= rsvpmaker_inline_styles(wpautop(do_shortcode($embed->post_content)));
		if(get_post_meta($post_id,'_rsvp_on',true))
		{
		$login_required = get_post_meta($post_id, '_rsvp_login_required', true);
		$rsvplink = ($login_required) ? wp_login_url( get_post_permalink( $post_id ) ) : get_post_permalink( $post_id );
		if(strpos($rsvplink,'?') )
			$rsvp_options["rsvplink"] = str_replace('?','&',$rsvp_options["rsvplink"]);
		$event_embed["content"] .= sprintf($rsvp_options['rsvplink'],$rsvplink);
		}
		return $event_embed;
}

function rsvpmaker_upcoming_email($atts) {
	$output = '';
	$weeks = (empty($atts["weeks"])) ? 4 : $atts["weeks"];
	$end = date('Y-m-d',strtotime('+'.$weeks.' weeks')). ' 23:59:59';
	$upcoming = get_future_events(' a1.meta_value < "'.$end.'"');
	foreach($upcoming as $embed)
		{
		$event = event_to_embed($embed->ID,$embed);
		$output .= $event["content"]."\n\n";
		}
	if(isset($atts["looking_ahead"]))
		{
			$weeksmore = $atts["looking_ahead"];
			$label = (empty($atts["looking_ahead_label"])) ? '<h2>Looking Ahead</h2>' : '<h2 class="looking_ahead">'.$atts["looking_ahead_label"].'</h2>';
			$extra = date('Y-m-d',strtotime($end .' +'.$weeksmore.' weeks')). ' 23:59:59';
			$upcoming = get_future_events(' a1.meta_value > "'.$end .'" AND  a1.meta_value < "'.$extra.'"');
			if(!empty($upcoming))
				{
					$output .= $label."\n";
					foreach($upcoming as $ahead)
						$output .= sprintf('<p><a href="%s">%s - %s</a></p>',get_permalink($ahead->ID),$ahead->post_title,date('F j',strtotime($ahead->datetime)));
				}
		}	
	return $output;
}

add_shortcode('rsvpmaker_upcoming_email','rsvpmaker_upcoming_email');

function is_email_context () {
		global $email_context;
		return (isset($email_context) && $email_context);
}

function rsvpmaker_cron_email_send($args) {
global $rsvpmaker_cron_context;
global $wp_query;
$rsvpmaker_cron_context = true;
$post_id = (int) $args;// single argument comes as single value
$wp_query = new WP_Query( array('post_type' => 'rsvpemail','p' => $post_id) );
include plugin_dir_path(__FILE__) . 'rsvpmaker-email-template.php';
}

add_action('rsvpmaker_cron_email','rsvpmaker_cron_email_send');


add_filter( 'post_row_actions', 'rsvpmaker_row_actions', 10, 2 );
function rsvpmaker_row_actions( $actions, WP_Post $post ) {
    if ( $post->post_type != 'rsvpmaker' ) {
        return $actions;
    }

    $actions['rsvpmaker_invite'] = sprintf('<a href="%s">%s</a>',admin_url('/post-new.php?post_type=rsvpemail&event=').$post->ID,__('Send Invitation','rsvpmaker'));
    return $actions;
}

//based on Austin Matzko's code from wp-hackers email list
function filter_where_recent($where = '') {
global $blog_weeks_ago;
if(0 == (int) $blog_weeks_ago)
	$blog_weeks_ago = 1;
	$week_ago_stamp = strtotime('-'.$blog_weeks_ago.' week');
	$week_ago = date('Y-m-d H:i:s',$week_ago_stamp);
    $where .= " AND post_date > '" . $week_ago . "'";
    return $where;
}

add_shortcode('rsvpmaker_recent_blog_posts','rsvpmaker_recent_blog_posts');

function rsvpmaker_recent_blog_posts ($atts) {
global $wp_query;
global $post;
$backup = $wp_query;
global $blog_weeks_ago;
$blog_weeks_ago = (!empty($atts["weeks"])) ? $atts["weeks"] : 1;
add_filter('posts_where', 'filter_where_recent');
query_posts('post_type=post');
if (have_posts()) :
$output = '<h3>'.__('From the Blog','rsvpmaker')."</h3>";
while (have_posts()) : the_post(); 
if($post->comment_count)
	$c = sprintf(" (%d comments)",$post->comment_count);
else
	$c = "";
$output .= '<h4><a href="'. get_permalink() .'" rel="bookmark">'. get_the_title() .'</a> By '. get_the_author() . $c . "</h4>\n".get_the_excerpt();
 endwhile;
endif;
remove_filter('posts_where', 'filter_where_recent');
$wp_query = $backup;
return $output;
}

?>